
# The different «fontWeight» options to show
options = [ 100, 200, 300, 400, 500, 600, 700, 800, 900, "normal", "bold" ]
defaultOption = 3  # 400 is the default


# Changing «fontFamily» to the default Apple system font
# (because this will work with all the weights)
theTextLayer.fontFamily = "-apple-system"


# Functions for the slider

# round number to a set amount
round = (number, nearest) ->
	Math.round(number / nearest) * nearest


# - add dots for increments to slider
# - enforce increments
# - change title on value change

applyIncrements = (slider,options) ->
	
	latestOption = null
	
	sizeOfDots = slider.height + 2
	stepAmount = options.length
	
	stepDistanceDots = ( slider.width - sizeOfDots ) / ( stepAmount - 1 )
	stepDistanceKnob = slider.width / ( stepAmount - 1 )
	
	for i in [0...stepAmount]
		dot = new Layer 
			size: sizeOfDots
			borderRadius: sizeOfDots / 1.5
			superLayer: slider
			backgroundColor: artboard.backgroundColor
			x: (stepDistanceDots * i)
		
		dot.placeBehind slider.knob
		dot.y = Align.center
	
	slider.min = 0
	slider.max = stepAmount-1
	
	# set to default option initially
	slider.value = defaultOption
	latestOption = options[defaultOption]
	
	slider.onValueChange ->
		if options[Utils.round @value] isnt latestOption
			# make the text a bit smaller
			theTextLayer.scale = 0.95
			# apply the new value
			theTextLayer.fontWeight = options[Utils.round @value]
			# scale back up
			theTextLayer.animate
				scale: 1
				options:
					time: .3
					curve: "Spring"
			
			latestOption = options[Utils.round @value]
		
		if (Utils.round @value) is defaultOption
			title.template =
				v: ""
				d: "«default»"
		else if typeof options[Utils.round @value] is "string"
			title.template =
				v: "\"#{options[Utils.round @value]}\""
				d: ""
		else
			title.template =
				v: options[Utils.round @value]
				d: ""
	
	slider.knob.draggable.updatePosition = (point) ->
		point.x = round(point.x, stepDistanceKnob) - (slider.knob.width / 2)
		return point

# Setup title
title.template =
	v: ""
	d: "«default»"

# Slider
slider = new SliderComponent
	height: 5
	width: Screen.width - 50
	knobSize: 25
	backgroundColor: "rgba(255,255,255,0.5)"
	x: 25
	maxY: Screen.height - 30
slider.fill.backgroundColor = "#fff"

# add interval points to the slider
applyIncrements slider, options
